@@ -58,6 +58,7 @@ class CmdClone(BaseCmd):
     $ resilient-sdk clone --workflow <workflow_to_be_cloned> <new_workflow_name>
     $ resilient-sdk clone --workflow <workflow_to_be_cloned> <new_workflow_name> --changetype artifact
     $ resilient-sdk clone -pb <playbook_to_be_cloned> <new_playbook_name>
+    $ resilient-sdk clone -pb <playbook_to_be_cloned> <new_playbook_name> --draft-playbook
     $ resilient-sdk clone --playbook <playbook_to_be_cloned> <new_playbook_name> --changetype artifact
     $ resilient-sdk clone -f <function_to_be_cloned> <new_function_name>
     $ resilient-sdk clone -r "Display name of Rule" "Cloned Rule display name"
@@ -85,9 +86,13 @@ class CmdClone(BaseCmd):
 
         self.parser.add_argument("-pb", "--playbook",
                                  type=ensure_unicode,
-                                 help="API names of playbooks to include. Only SOAR >= v{0} supported".format(constants.MIN_SOAR_SERVER_VERSION_PLAYBOOKS),
+                                 help="API names of playbooks to include. {0}".format(constants.INFO_MIN_PB_SUPPORT),
                                  nargs="*")
 
+        self.parser.add_argument("--draft-playbook",
+                                 action="store_true",
+                                 help="If specified with the '--playbook' option will clone the Playbook into a Draft state, allowing you to change it's Activation Type. {0}".format(constants.INFO_MIN_PB_SUPPORT))
+
         self.parser.add_argument("-r", "--rule",
                                  type=ensure_unicode,
                                  help="Display names of rules to include (surrounded by \"\")",
@@ -188,7 +193,10 @@ class CmdClone(BaseCmd):
                 if args.playbook:
 
                     if get_resilient_server_version(CmdClone.res_client) < constants.MIN_SOAR_SERVER_VERSION_PLAYBOOKS:
-                        raise SDKException(u"Playbooks are only supported with IBM SOAR >= {0}".format(constants.MIN_SOAR_SERVER_VERSION_PLAYBOOKS))
+                        raise SDKException(constants.ERROR_PLAYBOOK_SUPPORT)
+
+                    if args.draft_playbook:
+                        LOG.warning(constants.WARNING_DRAFT_PB_SIDE_EFFECTS)
 
                     # If a Playbook was provided, call _clone_action_object with Playbook related params and
                     # add the newly cloned Playbook to new_export_data
@@ -199,7 +207,8 @@ class CmdClone(BaseCmd):
                         obj_identifier=ResilientObjMap.PLAYBOOKS,
                         obj_key=constants.CUST_PLAYBOOKS,
                         replace_fn=CmdClone.replace_playbook_object_attrs,
-                        new_object_type=args.changetype)
+                        new_object_type=args.changetype,
+                        convert_to_draft=args.draft_playbook)
 
             add_configuration_import(new_export_data, CmdClone.res_client)
             # If any message destinations were cloned, after creation attach a Authorised User or API Key
@@ -325,7 +334,7 @@ class CmdClone(BaseCmd):
         return any([obj.get(ResilientObjMap.RULES, "") in specified_objs, obj.get(ResilientObjMap.WORKFLOWS, "") in specified_objs, obj.get(ResilientObjMap.FUNCTIONS, "") in specified_objs, obj.get(ResilientObjMap.DATATABLES, "") in specified_objs])
 
     @staticmethod
-    def _clone_action_object(input_args, org_export, obj_name, obj_identifier, obj_key, replace_fn, new_object_type=None):
+    def _clone_action_object(input_args, org_export, obj_name, obj_identifier, obj_key, replace_fn, new_object_type=None, convert_to_draft=False):
         CmdClone.validate_provided_args_length(input_args)
 
         original_obj_api_name, new_obj_api_name = input_args
@@ -337,7 +346,7 @@ class CmdClone(BaseCmd):
                                                                original_object_api_name=original_obj_api_name,
                                                                export=org_export)
 
-        cloned_object = replace_fn(original_obj.copy(), new_obj_api_name, changetype=new_object_type)
+        cloned_object = replace_fn(original_obj.copy(), new_obj_api_name, changetype=new_object_type, convert_to_draft=convert_to_draft)
         if new_object_type:
             cloned_object['object_type'] = new_object_type
 
@@ -582,7 +591,9 @@ class CmdClone(BaseCmd):
         new_field_type_uuid = u"{0}_{1}".format("playbook", pb_new_uuid.replace("-", "_"))
         playbook_xml = obj_to_modify.get("content", {}).get("xml", "")
         local_scripts = obj_to_modify.get("local_scripts")
+        fields_type = obj_to_modify.get("fields_type", {})
         changetype = kwargs.get("changetype", None)
+        convert_to_draft = kwargs.get("convert_to_draft", False)
 
         if local_scripts:
             for s in local_scripts:
@@ -618,17 +629,58 @@ class CmdClone(BaseCmd):
             }
         })
 
-        obj_to_modify.get("fields_type", {}).update({
+        fields_type.update({
             "display_name": new_obj_api_name,
             "type_name": new_field_type_uuid,
             "export_key": new_field_type_uuid,
             "uuid": str(uuid.uuid4())
         })
 
+        # if there are any activation fields, they need to be updated as well as they
+        # have export_key's and uuid's
+        fields = fields_type.get("fields", {})
+        for field in fields:
+            field_old_uuid = fields.get(field).get("uuid") # need old UUID to search in view_items list
+            field_new_uuid = str(uuid.uuid4())
+            fields.get(field).update({
+                "export_key": u"{0}/{1}".format(new_field_type_uuid, field),
+                "uuid": field_new_uuid
+            })
+            fields.get(field).pop("id")
+
+            # have to do a sequential search of the manual_settings.view_items
+            # to find the correct item which corresponds to the activation field modified above
+            # search is based on UUID, which is found in manual_settings.view_items[<index>].content
+            # and then the content value needs to be updated to match the new UUID and the field_type
+            # updated to match the new_field_type_uuid
+            for view_item in obj_to_modify.get("manual_settings", {}).get("view_items", []):
+                if view_item.get("content") == field_old_uuid:
+                    view_item.update({
+                        "content": field_new_uuid,
+                        "field_type": new_field_type_uuid
+                    })
+                    break
+
+        if obj_to_modify.get("tag"):
+            tag_new_name = "playbook_{0}".format(pb_new_uuid)
+            obj_to_modify.get("tag").update({
+                "display_name": tag_new_name,
+                "name": tag_new_name,
+                "uuid": str(uuid.uuid4())
+            })
+
         if changetype:
             obj_to_modify.update({
                 "object_type": changetype
             })
+
+        if convert_to_draft:
+            obj_to_modify.update({
+                "activation_type": None,
+                "activation_details": {},
+                "status": "draft"
+            })
+
         obj_to_modify.pop("id")
 
         return obj_to_modify
