@@ -32,6 +32,7 @@ class CmdCodegen(BaseCmd):
     $ resilient-sdk codegen -p <name_of_package> -m 'fn_custom_md' --rule 'Rule One' 'Rule Two' -i 'custom incident type'
     $ resilient-sdk codegen -p <name_of_package> -m 'fn_custom_md' -c '/usr/custom_app.config'
     $ resilient-sdk codegen -p <path_current_package> --reload --workflow 'new_wf_to_add'
+    $ resilient-sdk codegen -p <path_current_package> --poller
     $ resilient-sdk codegen -p <path_current_package> --gather-results
     $ resilient-sdk codegen -p <path_current_package> --gather-results '/usr/custom_app.log' -f 'func_one' 'func_two'"""
     CMD_DESCRIPTION = CMD_HELP
@@ -51,6 +52,10 @@ class CmdCodegen(BaseCmd):
                                  action="store_true",
                                  help="Reload customizations and create new customize.py")
 
+        self.parser.add_argument("-pr", "--poller",
+                                 action="store_true",
+                                 help="Build template files for a poller")
+
         self.parser.add_argument(constants.SUB_CMD_OPT_GATHER_RESULTS,
                                  action="store",
                                  nargs="?",
@@ -322,6 +327,12 @@ class CmdCodegen(BaseCmd):
 
         jinja_data["resilient_libraries_version"] = sdk_helpers.get_resilient_libraries_version_to_use()
 
+        # add poller flag
+        jinja_data["poller_flag"] = args.poller
+
+        # add ::CHANGE_ME:: to jinja data
+        jinja_data["change_me_str"] = constants.DOCGEN_PLACEHOLDER_STRING
+
         # Validate we have write permissions
         sdk_helpers.validate_dir_paths(os.W_OK, output_base)
 
@@ -374,6 +385,26 @@ class CmdCodegen(BaseCmd):
             }
         }
 
+        # poller logic if --poller flag was passed
+        if args.poller:
+            poller_mapping_dict = {
+                "__init__.py": ("package/poller/__init__.py.jinja2", jinja_data),
+                "poller.py": ("package/poller/poller.py.jinja2", jinja_data),
+                # data isn't rendered with jinja — these are default jinja templates to be modified
+                # by the developer who is implementing a poller
+                "data": {
+                    "soar_create_case.jinja": package_helpers.PATH_DEFAULT_POLLER_CREATE_TEMPLATE,
+                    "soar_update_case.jinja": package_helpers.PATH_DEFAULT_POLLER_UPDATE_TEMPLATE,
+                    "soar_close_case.jinja": package_helpers.PATH_DEFAULT_POLLER_CLOSE_TEMPLATE
+                }
+            }
+            lib_mapping_dict = {
+                "__init__.py": ("package/lib/__init__.py.jinja2", jinja_data),
+                "app_common.py": ("package/lib/app_common.py.jinja2", jinja_data)
+            }
+            package_mapping_dict[package_name]['poller'] = poller_mapping_dict
+            package_mapping_dict[package_name]['lib'] = lib_mapping_dict
+
         # If there are Functions, add a 'tests' and a 'payload_samples' directory (if in dev mode)
         if jinja_data.get("functions"):
             package_mapping_dict["tests"] = {}
