@@ -3,34 +3,43 @@
 # (c) Copyright IBM Corp. 2010, 2020. All Rights Reserved.
 
 """Common Helper Functions for the resilient-sdk"""
-import logging
-import keyword
-import re
-import os
-import sys
-import io
+import ast
 import copy
-import json
 import datetime
-import importlib
 import hashlib
+import importlib
+import io
+import json
+import keyword
+import logging
+import os
+import re
+import shlex
+import shutil
+import subprocess
+import sys
+import tempfile
 import time
 import uuid
-import shlex
-import subprocess
-import ast
-import pkg_resources
-import tempfile
-import shutil
 import xml.etree.ElementTree as ET
-from jinja2 import Environment, PackageLoader
-from zipfile import ZipFile, is_zipfile, BadZipfile
+from zipfile import BadZipfile, ZipFile, is_zipfile
+
+import pkg_resources
+import requests
 import requests.exceptions
-from resilient import ArgumentParser, get_config_file, get_client
-from resilient_sdk.util.sdk_exception import SDKException
-from resilient_sdk.util.resilient_objects import DEFAULT_INCIDENT_TYPE, DEFAULT_INCIDENT_FIELD, ResilientTypeIds, ResilientFieldTypes, ResilientObjMap
-from resilient_sdk.util.jinja2_filters import add_filters_to_jinja_env
+from jinja2 import Environment, PackageLoader
+from resilient import ArgumentParser
+from resilient import constants as res_constants
+from resilient import get_client, get_config_file
+from resilient.helpers import remove_tag
 from resilient_sdk.util import constants
+from resilient_sdk.util.jinja2_filters import add_filters_to_jinja_env
+from resilient_sdk.util.resilient_objects import (DEFAULT_INCIDENT_FIELD,
+                                                  DEFAULT_INCIDENT_TYPE,
+                                                  ResilientFieldTypes,
+                                                  ResilientObjMap,
+                                                  ResilientTypeIds)
+from resilient_sdk.util.sdk_exception import SDKException
 
 if sys.version_info.major < 3:
     # Handle PY 2 specific imports
@@ -68,7 +77,14 @@ def get_resilient_client(path_config_file=None):
 
     LOG.info("Connecting to IBM Security SOAR at: %s", opts.get("host"))
 
-    return get_client(opts)
+    retry_args = {
+        res_constants.APP_CONFIG_MAX_CONNECTION_RETRIES: opts.get(res_constants.APP_CONFIG_MAX_CONNECTION_RETRIES),
+        res_constants.APP_CONFIG_REQUEST_MAX_RETRIES: opts.get(res_constants.APP_CONFIG_REQUEST_MAX_RETRIES),
+        res_constants.APP_CONFIG_REQUEST_RETRY_DELAY: opts.get(res_constants.APP_CONFIG_REQUEST_RETRY_DELAY),
+        res_constants.APP_CONFIG_REQUEST_RETRY_BACKOFF: opts.get(res_constants.APP_CONFIG_REQUEST_RETRY_BACKOFF)
+    }
+
+    return get_client(opts, **retry_args)
 
 
 def setup_jinja_env(relative_path_to_templates):
@@ -114,6 +130,28 @@ def write_file(path, contents):
         the_file.write(contents)
 
 
+def write_latest_pypi_tmp_file(latest_version, path_sdk_tmp_pypi_version):
+    """
+    Writes the ``latest_version`` and the ts of the current time
+    to ``path_sdk_tmp_pypi_version``
+
+    If ``latest_version`` is a ``pkg_resources.Version``, get its ``base_version``.
+    Note: this is actually a different Version type - we would have to import extra
+    dependencies to correctly use isinstance(latest_version, Version) - so just checking
+    if it has the attribute
+    """
+    # Try get the 'base_version' if this is a Version object
+    if isinstance(latest_version, object):
+        latest_version = getattr(latest_version, "base_version", latest_version)
+
+    saved_version_data = {
+        "ts": int(time.time()),
+        "version": latest_version
+    }
+
+    write_file(path_sdk_tmp_pypi_version, json.dumps(saved_version_data))
+
+
 def read_file(path):
     """Returns all the lines of a file at path as a List"""
     file_lines = []
@@ -746,7 +784,7 @@ def get_from_export(export,
 
     # Get Playbooks
     if playbooks and constants.CURRENT_SOAR_SERVER_VERSION and constants.CURRENT_SOAR_SERVER_VERSION < constants.MIN_SOAR_SERVER_VERSION_PLAYBOOKS:
-        raise SDKException("Playbooks are only supported in {0} for SOAR >= {1}. Current version: {2}.".format(constants.SDK_RESOURCE_NAME, constants.MIN_SOAR_SERVER_VERSION_PLAYBOOKS, constants.CURRENT_SOAR_SERVER_VERSION))
+        raise SDKException(constants.ERROR_PLAYBOOK_SUPPORT)
     else:
         return_dict["playbooks"] = get_res_obj("playbooks", ResilientObjMap.PLAYBOOKS, "Playbook", playbooks, export)
 
@@ -774,6 +812,8 @@ def minify_export(export,
 
     :param export: The result of calling get_latest_org_export()
     :type export: Dict
+    :param keys_to_keep: Keys that should remain unchanged from the original export
+    :type keys_to_keep: Dict
     :param message_destinations: List of Message Destination API Names
     :param functions: List of Function API Names
     :param workflows: List of Workflow API Names
@@ -793,6 +833,8 @@ def minify_export(export,
     minified_export = copy.deepcopy(export)
 
     # If no keys_to_keep are specified, use these defaults
+    # keys_to_keep is used to keep values from the original export
+    # without being minified
     if not keys_to_keep:
         keys_to_keep = [
             "export_date",
@@ -801,6 +843,13 @@ def minify_export(export,
             "server_version"
         ]
 
+    # certain keys need to be cleared, rather than set to empty objects
+    # so as not to process a delete or update on the platform when the
+    # export is modified and POSTed back to SOAR
+    keys_to_clear = [
+        "overrides"
+    ]
+
     # some incident types are parent/child. This routine will return all the parent incident types
     parent_child_incident_types = find_parent_child_types(export, "incident_types", "name", incident_types)
 
@@ -849,6 +898,9 @@ def minify_export(export,
                     if not data.get(attribute_name, "").strip() in values:
                         minified_export[key].remove(data)
 
+        elif key in keys_to_clear:
+            minified_export[key] = None
+
         elif isinstance(minified_export[key], list):
             minified_export[key] = []
 
@@ -869,8 +921,52 @@ def minify_export(export,
     if "incident/" not in fields:
         minified_export["fields"].append(DEFAULT_INCIDENT_FIELD)
 
+    # Clean out any pii values with keys included in pii_key_list
+    pii_key_list = ["creator", "creator_id"]
+    minified_export = rm_pii(pii_key_list, minified_export)
+
+    minified_export = remove_tag(minified_export)
+
     return minified_export
 
+
+def rm_pii(pii_key_list, export):
+    """
+    Remove any keys from 'export' that are in 'pii_key_list'.
+    Recursively searches the export object.
+    
+    :param pii_key_list: list of str keys to be removed from 'export'. ex: ["creator", "creator_id"]
+    :type pii_key_list: [str]
+    :param export: the result of calling get_latest_org_export() or minified_export from calling minify_export()
+    :type export: Dict
+    :return: modified export with any pii keys removed
+    :rtype: Dict
+    """
+
+    if export:
+        export_copy = export.copy()
+
+        for key in list(export_copy.keys()):
+            content = export_copy[key]
+
+            # if key is in pii_list to remove, delete entry in payload_result
+            if key in pii_key_list:
+                del export_copy[key]
+                continue
+
+            # if key wasn't in pii_list, continue searching recursively for dictionaries and scrubbing pii
+            if isinstance(content, dict):
+                export_copy[key] = rm_pii(pii_key_list, content)
+            elif isinstance(content, list):
+                # recreates the list where any dict elements of the list are recursively scrubbed
+                # if list item is not a dictionary, don't 
+                export_copy[key] = [rm_pii(pii_key_list, list_content) if isinstance(list_content, dict) else list_content for list_content in content]
+
+        return export_copy
+    else:
+        return export
+
+
 def find_parent_child_types(export, object_type, attribute_name, name_list):
     """[get all parent objects (like incident_types)]
 
@@ -1136,7 +1232,7 @@ def get_package_version(package_name):
     Uses pkg_resources to parse the version of a package if installed in the environment.
     If not installed, return None
 
-    :param package_name: name of the packge to get version of
+    :param package_name: name of the package to get version of
     :type package_name: str
     :return: a Version object representing the version of the given package or None
     :rtype: Version or None
@@ -1147,6 +1243,111 @@ def get_package_version(package_name):
         return None
 
 
+def get_latest_version_on_pypi():
+    """
+    Uses requests to call 'https://pypi.org/pypi/resilient-sdk/json'
+    to get a JSON dict of all the available versions on PyPi.
+    Sorts the dict into a list, then gets the latest
+
+    :raises HTTPError: if a problem occurs reaching pypi.org
+    :return: the latest available version of this library on PyPi
+    :rtype: pkg_resources.extern.packaging.version.Version
+    """
+    r = requests.get(constants.URL_PYPI_VERSION, timeout=5)
+    r.raise_for_status()
+
+    res_json = r.json()
+
+    available_versions = []
+
+    for the_version in res_json.get("releases", {}):
+
+        v = pkg_resources.parse_version(the_version)
+
+        if not isinstance(v, pkg_resources.extern.packaging.version.LegacyVersion):
+            available_versions.append(v)
+
+    available_versions = sorted(available_versions)
+
+    return available_versions[-1]
+
+
+def get_latest_available_version():
+    """
+    Sees if the latest version is stored in a tmp file
+    and if the file is missing or the timestamp is older
+    than 3 days, gets the latest version from PyPi
+
+    :return: the latest available version of this library on PyPi
+    :rtype: pkg_resources.Version
+    """
+    latest_available_version = None
+
+    sdk_tmp_dir = get_sdk_tmp_dir()
+    path_sdk_tmp_pypi_version = os.path.join(sdk_tmp_dir, constants.TMP_PYPI_VERSION)
+
+    if os.path.isfile(path_sdk_tmp_pypi_version):
+        pypi_version_data = read_json_file(path_sdk_tmp_pypi_version)
+
+        now = datetime.datetime.now()
+        ts = datetime.datetime.fromtimestamp(pypi_version_data.get("ts", ""))
+        refresh_pypi_date = ts + datetime.timedelta(days=3)
+
+        if now > refresh_pypi_date:
+            latest_available_version = get_latest_version_on_pypi()
+            write_latest_pypi_tmp_file(latest_available_version, path_sdk_tmp_pypi_version)
+
+        else:
+            return pkg_resources.parse_version(pypi_version_data.get("version", ""))
+
+    else:
+        latest_available_version = get_latest_version_on_pypi()
+        write_latest_pypi_tmp_file(latest_available_version, path_sdk_tmp_pypi_version)
+
+    return latest_available_version
+
+
+def create_tmp_dir(sdk_tmp_dir_name=constants.SDK_RESOURCE_NAME, tmp_dir=tempfile.gettempdir()):
+    """
+    Checks if user has correct permissions then creates
+    the sdk_tmp_dir
+
+    :param sdk_tmp_dir_name: the name for the dir to create in the system's /tmp folder
+    :type sdk_tmp_dir_name: str
+    :param tmp_dir: the path to the temp files location on the system
+    :type tmp_dir: str
+    :return: path to the sdk_tmp_dir
+    :rtype: str
+    """
+    validate_dir_paths(os.W_OK, tmp_dir)
+
+    path_sdk_tmp_dir = os.path.join(tmp_dir, sdk_tmp_dir_name)
+
+    os.makedirs(path_sdk_tmp_dir)
+
+    return path_sdk_tmp_dir
+
+
+def get_sdk_tmp_dir(sdk_tmp_dir_name=constants.SDK_RESOURCE_NAME, tmp_dir=tempfile.gettempdir()):
+    """
+    Gets the path to the sdk_tmp_dir or creates it if it does
+    not exist
+
+    :param sdk_tmp_dir_name: the name for the dir normally the name of the package
+    :type sdk_tmp_dir_name: str
+    :param tmp_dir: the path to the temp files location on the system
+    :type tmp_dir: str
+    :return: path to the sdk_tmp_dir
+    :rtype: str
+    """
+    path_sdk_tmp_dir = os.path.join(tmp_dir, sdk_tmp_dir_name)
+
+    if not os.path.isdir(path_sdk_tmp_dir):
+        path_sdk_tmp_dir = create_tmp_dir(sdk_tmp_dir_name, tmp_dir)
+
+    return path_sdk_tmp_dir
+
+
 def is_python_min_supported_version(custom_warning=None):
     """
     Logs a WARNING if the current version of Python is not >= MIN_SUPPORTED_PY_VERSION
@@ -1303,29 +1504,6 @@ def run_subprocess(args, change_dir=None, cmd_name="", log_level_threshold=loggi
     return proc.returncode, details
 
 
-    """ OLD code with a progress bar -- keeping this here for potentially picking it back up later """
-
-    # start_time = time.time()
-
-    # # "waiting bar" that spins while waiting for proc to finish
-    # # the waiting bar is only output if the logging threshold is not met
-    # waiting_bar = ("-", "\\", "|", "/", "-", "\\", "|", "/")
-    # i = 0
-    # details = ""
-    # while proc.poll() == None and (time.time() - start_time) < timeout:
-    #     sys.stdout.write("\r")
-    #     sys.stdout.write("Running {0} ... {1}        ".format(cmd_name, waiting_bar[i]))
-    #     sys.stdout.flush()
-    #     i = (i + 1) % len(waiting_bar)
-    #     time.sleep(0.2)
-
-
-    # # overwrite the last stdout.write of "Running <cmd_name> ..."
-    # sys.stdout.write("\r")
-    # sys.stdout.write(" "*30+"\n")
-    # sys.stdout.flush()
-
-
 def scrape_results_from_log_file(path_log_file):
     """
     Validate that path_log_file exists, reverse it and look for lines
