@@ -9,86 +9,101 @@ from resilient_sdk.util import package_file_helpers as package_helpers
 from resilient_sdk.util import sdk_helpers, sdk_validate_helpers
 from resilient_sdk.util.sdk_validate_issue import SDKValidateIssue
 
+DEFAULT_SETUP_ATTR_REGEX = r"^<<|>>$"
+
 # formatted strings follow array of values: [attr, attr_value, <OPTIONAL: fail_msg_lambda_supplement>]
-setup_py_attributes = {
-    "name": {
+setup_py_attributes = [
+    ("name", {
         "parse_func": package_helpers.parse_setup_py,
-        "fail_func": lambda x: re.findall(r"[^a-z_0-9]+", x),
+        "fail_func": lambda x: re.findall(r"[^a-z_0-9]+", x, re.IGNORECASE),
         "fail_msg": u"setup.py attribute '{0}' has invalid character(s) in '{1}'",
         "missing_msg": u"setup.py file is missing attribute '{0}' or missing the value for the attribute",
         "solution": u"Make sure that '{0}' is all lowercase and contains only letters, numbers or underscores",
         "severity": SDKValidateIssue.SEVERITY_LEVEL_CRITICAL
-    },
-    "display_name": {
+    }),
+    ("display_name", {
         "parse_func": package_helpers.parse_setup_py,
-        "fail_func": lambda x: re.findall(r"^<<|>>$", x),
+        "fail_func": lambda x: re.findall(DEFAULT_SETUP_ATTR_REGEX, x, re.IGNORECASE),
         "fail_msg": u"setup.py attribute '{0}' remains unchanged from the default value '{1}'", 
         "missing_msg": u"setup.py file is missing attribute '{0}' or missing the value for the attribute",
         "solution": u"Set '{0}' to an appropriate value. This value is displayed when the app is installed",
         "severity": SDKValidateIssue.SEVERITY_LEVEL_WARN
-    },
-    "license": {
+    }),
+    ("display_name", {
         "parse_func": package_helpers.parse_setup_py,
-        "fail_func": lambda x: re.findall(r"^<<|>>$", x),
+        "fail_func": sdk_validate_helpers.check_display_name_not_equal_to_name,
+        "include_setup_py_path_in_fail_func": True,
+        "fail_msg": u"'{0}' should not be the same as 'name'", 
+        "solution": u"Set '{0}' to a value that will be displayed when installed on App Host",
+        "severity": SDKValidateIssue.SEVERITY_LEVEL_CRITICAL
+    }),
+    ("license", {
+        "parse_func": package_helpers.parse_setup_py,
+        "fail_func": lambda x: re.findall(DEFAULT_SETUP_ATTR_REGEX, x, re.IGNORECASE),
         "fail_msg": u"setup.py attribute '{0}' remains unchanged from the default value '{1}'", 
         "missing_msg": u"setup.py file is missing attribute '{0}' or missing the value for the attribute",
         "solution": u"Set '{0}' to an valid license.",
         "severity": SDKValidateIssue.SEVERITY_LEVEL_CRITICAL
-    },
-    "url": {
+    }),
+    ("url", {
         "parse_func": package_helpers.parse_setup_py,
         "fail_func": lambda x: not sdk_helpers.is_valid_url(x),
         "fail_msg": u"'{1}' is not a valid '{0}'",
         "missing_msg": "'url' is a recommended attribute",
         "solution": "Include a valid URL for your organization",
         "severity": SDKValidateIssue.SEVERITY_LEVEL_WARN
-    },
-    "author": {
+    }),
+    ("author", {
         "parse_func": package_helpers.parse_setup_py,
-        "fail_func": lambda x: re.findall(r"^<<|>>$", x),
+        "fail_func": lambda x: re.findall(DEFAULT_SETUP_ATTR_REGEX, x, re.IGNORECASE),
         "fail_msg": u"setup.py attribute '{0}' remains unchanged from the default value '{1}'", 
         "missing_msg": u"setup.py file is missing attribute '{0}' or missing the value for the attribute",
         "solution": u"Set '{0}' to the name of the author",
         "severity": SDKValidateIssue.SEVERITY_LEVEL_CRITICAL
-    },
-    "author_email": {
+    }),
+    ("author_email", {
         "parse_func": package_helpers.parse_setup_py,
-        "fail_func": lambda x: re.findall(r"@example\.com", x),
+        "fail_func": lambda x: re.findall(r"@example\.com", x, re.IGNORECASE),
         "fail_msg": u"setup.py attribute '{0}' remains unchanged from the default value '{1}'", 
         "missing_msg": u"setup.py file is missing attribute '{0}' or missing the value for the attribute",
         "solution": u"Set '{0}' to the author's contact email",
         "severity": SDKValidateIssue.SEVERITY_LEVEL_CRITICAL
-    },
-    "description": {
+    }),
+    ("description", {
         "parse_func": package_helpers.parse_setup_py,
-        "fail_func": lambda x: re.findall(r"^(Resilient Circuits Components).*", x),
+        "fail_func": lambda x: re.findall(r"{0}.*".format(constants.DOCGEN_PLACEHOLDER_STRING), x, re.IGNORECASE),
         "fail_msg": u"setup.py attribute '{0}' remains unchanged from the default value '{1:29.29}...'", 
         "missing_msg": u"setup.py file is missing attribute '{0}' or missing the value for the attribute",
-        "solution": u"Enter text that describes the app in '{0}'. This will be displayed when the app is installed",
+        "solution": u"Enter a quick description for the app in '{0}'. This will be displayed when the app is installed",
         "severity": SDKValidateIssue.SEVERITY_LEVEL_WARN
-    },
-    "long_description": {
+    }),
+    ("long_description", {
         "parse_func": package_helpers.parse_setup_py,
-        "fail_func": lambda x: re.findall(r"^(Resilient Circuits Components).*", x),
+        "fail_func": lambda x: re.findall(r"{0}.*".format(constants.DOCGEN_PLACEHOLDER_STRING), x, re.IGNORECASE),
         "fail_msg": u"setup.py attribute '{0}' remains unchanged from the default value '{1:29.29}...'",
         "missing_msg": u"setup.py file is missing attribute '{0}' or missing the value for the attribute",
-        "solution": u"Enter text that describes the app in '{0}'. This will be displayed when the app is installed",
+        "solution": u"Enter a detailed description for the app in '{0}'. This will be displayed when the app is installed",
         "severity": SDKValidateIssue.SEVERITY_LEVEL_WARN
-    },
-    "install_requires": {
+    }),
+    ("install_requires", {
         "parse_func": package_helpers.parse_setup_py,
-        "fail_func": lambda x: False 
-            if package_helpers.get_dependency_from_install_requires(x, "resilient_circuits") is not None 
-            else False if package_helpers.get_dependency_from_install_requires(x, "resilient-circuits") is not None
-            else True,
+        "fail_func": lambda x: package_helpers.get_dependency_from_install_requires(x, constants.CIRCUITS_PACKAGE_NAME) is None,
         "fail_msg": u"'resilient_circuits' must be included as a dependency in '{0}'. Found '{1}'",
-        "missing_msg": u"'resilient_circuits' must be included as a dependency in '{0}'",
+        "missing_msg": u"'install_requires' is required in setup.py",
         "solution": u"Include 'resilient_circuits>={0}' as a requirement in '{1}'".format(
             constants.RESILIENT_LIBRARIES_VERSION, "{0}"
         ),
         "severity": SDKValidateIssue.SEVERITY_LEVEL_CRITICAL
-    },
-    "python_requires": {
+    }),
+    ("install_requires", {
+        "parse_func": package_helpers.parse_setup_py,
+        "fail_func": lambda x: bool(sdk_validate_helpers.check_dependencies_version_specifiers(x)),
+        "fail_msg": u"'{0}' has the following improperly formatted dependencies: {2}",
+        "fail_msg_lambda_supplement": lambda x: sdk_validate_helpers.check_dependencies_version_specifiers(x),
+        "solution": u"All dependencies (other than resilient-circuits) must be include a version in the format '~=' or '=='",
+        "severity": SDKValidateIssue.SEVERITY_LEVEL_WARN
+    }),
+    ("python_requires", {
         "parse_func": package_helpers.parse_setup_py,
         "fail_func": lambda x: package_helpers.get_required_python_version(x) < constants.MIN_SUPPORTED_PY_VERSION,
         "fail_msg": u"'{0}' version '{2[0]}.{2[1]}' is not supported",
@@ -99,8 +114,8 @@ setup_py_attributes = {
             constants.MIN_SUPPORTED_PY_VERSION[1]
         ),
         "severity": SDKValidateIssue.SEVERITY_LEVEL_WARN
-    },
-    "entry_points": {
+    }),
+    ("entry_points", {
         "parse_func": package_helpers.parse_setup_py,
         "fail_func": lambda x: False if not any([ep not in x for ep in package_helpers.SUPPORTED_EP]) else True,
         "fail_msg": u"'{0}' is missing {2} which is one of the required entry points", 
@@ -108,8 +123,8 @@ setup_py_attributes = {
         "missing_msg": u"'{0}' is missing",
         "solution": "Make sure that all of the following values for '{0}' are implemented: " + str(package_helpers.SUPPORTED_EP),
         "severity": SDKValidateIssue.SEVERITY_LEVEL_CRITICAL
-    }
-}
+    })
+]
 
 
 # NOTE: selftest_attributes needs to be a list as the order of these checks MATTERS
@@ -173,8 +188,8 @@ selftest_attributes = [
 
 
 # check package files are present
-package_files = {
-    "MANIFEST.in": {
+package_files = [ 
+    ("MANIFEST.in", {
         "func": sdk_validate_helpers.package_files_manifest,
         "name": "'MANIFEST.in'",
 
@@ -187,8 +202,9 @@ package_files = {
         "missing_solution": "Reload code using '''resilient-sdk codegen -p {0} --reload'''",
 
         "pass_msg": "'MANIFEST.in' has the minimum files included"
-    },
-    "apikey_permissions.txt": {
+    }),
+
+    ("apikey_permissions.txt", {
         "func": sdk_validate_helpers.package_files_apikey_pem,
         "name": "'apikey_permissions.txt'",
 
@@ -202,10 +218,11 @@ package_files = {
 
         "pass_msg": "'apikey_permissions.txt' is valid; it contains the base permissions",
         "pass_solution": "Permissions found: {0}"
-    },
-    "Dockerfile": {
+    }),
+
+    ("Dockerfile", {
         "func": sdk_validate_helpers.package_files_template_match,
-        "name": "'Dockerfile'",
+        "name": "'Dockerfile, template match'",
 
         "fail_msg": "'Dockerfile' does not match the template file ({0:.0f}% match). Difference from template:\n\n\t\t{1}",
         "fail_severity": SDKValidateIssue.SEVERITY_LEVEL_WARN,
@@ -216,8 +233,19 @@ package_files = {
         "missing_solution": "Reload code using '''resilient-sdk codegen -p {0} --reload'''",
 
         "pass_msg": "'Dockerfile' matches the template"
-    },
-    "entrypoint.sh": {
+    }),
+    ("Dockerfile", {
+        "func": sdk_validate_helpers.package_files_validate_base_image,
+        "name": "'Dockerfile, base image'",
+
+        "fail_msg": "Dockerfile is not using the correct base image: {0}", 
+        "fail_severity": SDKValidateIssue.SEVERITY_LEVEL_CRITICAL,
+        "fail_solution": "This can be fixed by {0}", 
+
+        "pass_msg": "Dockerfile is using the correct base image"
+        }),
+
+    ("entrypoint.sh", {
         "func": sdk_validate_helpers.package_files_template_match,
         "name": "'entrypoint.sh'",
 
@@ -230,8 +258,9 @@ package_files = {
         "missing_solution": "Reload code using '''resilient-sdk codegen -p {0} --reload'''",
 
         "pass_msg": "'entrypoint.sh' matches the template file"
-    },
-    "config.py": {
+    }),
+
+    ("config.py", {
         "func": sdk_validate_helpers.package_files_validate_config_py,
         "path": "{0}/util/config.py",
         "name": "'config.py'",
@@ -250,8 +279,9 @@ package_files = {
 
         "pass_msg": "'config.py' returned a valid app.config value",
         "pass_solution": u"config data: \n\t\t{0}"
-    },
-    "customize.py": {
+    }),
+
+    ("customize.py", {
         "func": sdk_validate_helpers.package_files_validate_customize_py,
         "path": "{0}/util/customize.py",
         "name": "'customize.py'",
@@ -266,8 +296,9 @@ package_files = {
 
         "pass_msg": "'customize.py' returned a valid import definition",
         "pass_solution": u"ImportDefinition found: {0}...; View the entire contents at '{1}'"
-    },
-    "README.md": {
+    }),
+
+    ("README.md", {
         "func": sdk_validate_helpers.package_files_validate_readme,
         "name": "'README.md'",
 
@@ -293,8 +324,9 @@ package_files = {
 
         "pass_msg": "'README.md' has been implemented",
         "pass_solution": "Make sure that all documentation is up to date before packaging"
-    },
-    "app_logo.png": {
+    }),
+
+    ("app_logo.png", {
         "func": sdk_validate_helpers.package_files_validate_icon,
         "path": package_helpers.PATH_ICON_EXTENSION_LOGO,
         "default_path": package_helpers.PATH_DEFAULT_ICON_EXTENSION_LOGO,
@@ -313,8 +345,9 @@ package_files = {
 
         "pass_msg": "'{0}' icon found at {1}",
         "solution": "Icons appear in SOAR when your app is installed with App Host"
-    },
-    "company_logo.png": {
+    }),
+
+    ("company_logo.png", {
         "func": sdk_validate_helpers.package_files_validate_icon,
         "path": package_helpers.PATH_ICON_COMPANY_LOGO,
         "default_path": package_helpers.PATH_DEFAULT_ICON_COMPANY_LOGO,
@@ -333,8 +366,9 @@ package_files = {
 
         "pass_msg": "'{0}' icon found at {1}",
         "solution": "Icons appear in SOAR when your app is installed with App Host"
-    },
-    "LICENSE": {
+    }),
+
+    ("LICENSE", {
         "func": sdk_validate_helpers.package_files_validate_license,
         "path": "{0}/LICENSE",
         "name": "LICENSE",
@@ -349,8 +383,8 @@ package_files = {
 
         "pass_msg": "'LICENSE' file is valid",
         "pass_solution": "It is recommended to manually validate the license. Suggested formats: MIT, Apache, and BSD"
-    }
-}
+    })
+ ]
 
 payload_samples_attributes = {
     "func": sdk_validate_helpers.payload_samples_validate_payload_samples,
